"""Global configs of the library."""

from __future__ import annotations

TORCH_VERSION = "N/A"
TORCH_AVAILABLE = False


TF_VERSION = "N/A"
TF_AVAILABLE = False


JAX_VERSION = "N/A"
JAX_AVAILABLE = False


# File Names
SYS_OUTPUT_INFO_FILENAME = "system_analysis.json"
CUSTOMIZED_FEATURES_CONFIG_FILE = "dataset_custom_features.json"
